@@ -1,8 +1,8 @@
 from pathlib import Path
 
 import typer
+from git import Repo
 
-from .git import clone
 from .parser import InvalidGitUrl, parse
 
 home = str(Path.home())
@@ -19,7 +19,7 @@ def get(url: str) -> None:
     """Clones a git repository"""
     try:
         target_directory = Path.home() / 'source' / parse(url)
-        clone(url, str(target_directory))
+        Repo.clone_from(url, str(target_directory))
     except InvalidGitUrl as exception:
         print(exception)
 
